@@ -1,4 +1,4 @@
-/* $Id: amber_BeamPos.c,v 1.19 2011/10/07 08:58:33 agabasch Exp $
+/* $Id: amber_BeamPos.c,v 1.20 2013-09-16 14:56:43 agabasch Exp $
  *
  * This file is part of the AMBER Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: agabasch $
- * $Date: 2011/10/07 08:58:33 $
- * $Revision: 1.19 $
- * $Name: amber-4_2_2 $
+ * $Date: 2013-09-16 14:56:43 $
+ * $Revision: 1.20 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -314,7 +314,7 @@ cpl_propertylist * BeamPosCreateProductHeader( const char * fctid, char * szRawF
      {
        /* Error */
        sprintf( szMessage, "Error in setting up the product header." ); 
-       cpl_msg_info( fctid, szMessage ); 
+       cpl_msg_info( fctid, "%s", szMessage ); 
        iStatus = 16;
      }
 #else 
@@ -329,7 +329,7 @@ cpl_propertylist * BeamPosCreateProductHeader( const char * fctid, char * szRawF
      {
        /* Error */
        sprintf( szMessage, "Error in setting up the product header." ); 
-       cpl_msg_info( fctid, szMessage ); 
+       cpl_msg_info( fctid, "%s", szMessage ); 
        iStatus = 16;
      }
 
@@ -973,17 +973,6 @@ static int amber_BeamPos_create(cpl_plugin * plugin)
     recipe->parameters = cpl_parameterlist_new() ; 
 
     /* Fill the parameters list */
-    /* --stropt */
-    p = cpl_parameter_new_value("amber.amber_BeamPos.str_option", 
-            CPL_TYPE_STRING, "the string option", "amber.amber_BeamPos",NULL);
-    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "stropt") ;
-    cpl_parameterlist_append(recipe->parameters, p) ;
-
-    /* binning int */
-    p = cpl_parameter_new_value("amber.amber_BeamPos.int_binning", 
-            CPL_TYPE_INT, "Number of Frames to be averaged per Visibility", "amber.amber_BeamPos", 1 ) ;
-    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "binning") ;
-    cpl_parameterlist_append(recipe->parameters, p) ;
  
     /* Return */
     return 0;
@@ -1116,7 +1105,7 @@ static int amber_BeamPos(
          iFrameCount++; /* Count BEAMPOS-frames only */
 
          sprintf( szMessage, "Frame #%d of 22 [Current execution status=%d]", iFrameCount, iStatus );
-         cpl_msg_info( fctid, szMessage );   
+         cpl_msg_info( fctid, "%s", szMessage );   
          
 	if( iStatus == 0 )      
 	{	
@@ -1124,7 +1113,7 @@ static int amber_BeamPos(
           if( amdlibLoadRawData(pszFilename, &rawData, errMsg) != amdlibSUCCESS )
           {
             sprintf ( szMessage, "Could not load raw data file '%s'", pszFilename );
-            cpl_msg_info( fctid, szMessage );   
+            cpl_msg_info( fctid, "%s", szMessage );   
             iStatus = 20;
           }
 	  else
@@ -1144,7 +1133,7 @@ static int amber_BeamPos(
 	  if( CalculateQCParams( pImage, &dPosX, &dPosY, &dSizeX, &dSizeY, &dFlux, &dAngle, &dPeakFlux) != 0 )
 	  {
             sprintf( szMessage, "Beam localization failed!" );		  
-            cpl_msg_info( fctid, szMessage );
+            cpl_msg_info( fctid, "%s", szMessage );
 	    dPosX  = 0;
 	    dPosY  = 0;
 	    dSizeX = 0;
@@ -1170,7 +1159,7 @@ static int amber_BeamPos(
 	  sprintf( szProduct, "amber_beampos_%04d.fits", iFrameCount );
 	  
        	  sprintf( szMessage, "%s %s", szProduct, szPrefix );
-          cpl_msg_info( fctid, szMessage );
+          cpl_msg_info( fctid, "%s", szMessage );
 
 	  pFrameProduct = cpl_frame_new();
           cpl_frame_set_filename( pFrameProduct, szProduct ); 
@@ -1184,60 +1173,60 @@ static int amber_BeamPos(
 
 	  sprintf( szQCParameter, "%sX", szPrefix );
  	  sprintf( szMessage, "%s = %.2f", szQCParameter, dPosX );
-          cpl_msg_info( fctid, szMessage );
+          cpl_msg_info( fctid, "%s", szMessage );
 	  cpl_propertylist_append_float( qc_properties, szQCParameter, dPosX ); 
 
  	  sprintf( szQCParameter, "%sY", szPrefix );
  	  sprintf( szMessage, "%s = %.2f", szQCParameter, dPosY );
-          cpl_msg_info( fctid, szMessage );
+          cpl_msg_info( fctid, "%s", szMessage );
 	  cpl_propertylist_append_float( qc_properties, szQCParameter, dPosY ); 
 
 
 	  sprintf( szQCParameter, "%sSHX", szPrefix );
  	  sprintf( szMessage, "%s = %.2f", szQCParameter, dOffsetX );
-          cpl_msg_info( fctid, szMessage );
+          cpl_msg_info( fctid, "%s", szMessage );
 	  cpl_propertylist_append_float( qc_properties, szQCParameter, dOffsetX ); 
 
  	  sprintf( szQCParameter, "%sSHY", szPrefix );
  	  sprintf( szMessage, "%s = %.2f", szQCParameter, dOffsetY );
-          cpl_msg_info( fctid, szMessage );
+          cpl_msg_info( fctid, "%s", szMessage );
 	  cpl_propertylist_append_float( qc_properties, szQCParameter, dOffsetY ); 
 
   	  sprintf( szQCParameter, "%sSIZX", szPrefix );
  	  sprintf( szMessage, "%s = %.2f", szQCParameter, dSizeX );
-          cpl_msg_info( fctid, szMessage );
+          cpl_msg_info( fctid, "%s", szMessage );
 	  cpl_propertylist_append_float( qc_properties, szQCParameter, dSizeX ); 
 
  	  sprintf( szQCParameter, "%sSIZY", szPrefix );
  	  sprintf( szMessage, "%s = %.2f", szQCParameter, dSizeY );
-          cpl_msg_info( fctid, szMessage );
+          cpl_msg_info( fctid, "%s", szMessage );
 	  cpl_propertylist_append_float( qc_properties, szQCParameter, dSizeY ); 
 
    	  sprintf( szQCParameter, "%sFLUX", szPrefix );
  	  sprintf( szMessage, "%s = %.2f", szQCParameter, dFlux );
-          cpl_msg_info( fctid, szMessage );
+          cpl_msg_info( fctid, "%s", szMessage );
 	  cpl_propertylist_append_float( qc_properties, szQCParameter, dFlux ); 
 
    	  sprintf( szQCParameter, "%sPEAKFLUX", szPrefix );
  	  sprintf( szMessage, "%s = %.2f", szQCParameter, dPeakFlux );
-          cpl_msg_info( fctid, szMessage );
+          cpl_msg_info( fctid, "%s", szMessage );
 	  cpl_propertylist_append_float( qc_properties, szQCParameter, dPeakFlux ); 
 
     	  sprintf( szQCParameter, "%sANGLE", szPrefix );
  	  sprintf( szMessage, "%s = %.2f", szQCParameter, dAngle );
-          cpl_msg_info( fctid, szMessage );
+          cpl_msg_info( fctid, "%s", szMessage );
 	  cpl_propertylist_append_float( qc_properties, szQCParameter, dAngle ); 
 
 	  /* Save Product */	
      	  /*sprintf( szMessage, "Saving Product %s %s...", szProduct, szPrefix );
-          cpl_msg_info( fctid, szMessage );*/
+          cpl_msg_info( fctid, "%s", szMessage );*/
 
 	  /*Adding the JMMC acknowledgements*/
 	  amber_JMMC_acknowledgement(qc_properties);
 
 	  cpl_image_save( pImage, szProduct, CPL_BPP_IEEE_FLOAT, qc_properties, CPL_IO_DEFAULT );
 	  /*sprintf( szMessage, "cpl_frame_insert (\"%s\")", cpl_frame_get_filename(pFrameProduct)  ); */
-          /*cpl_msg_info( fctid, szMessage );     */
+          /*cpl_msg_info( fctid, "%s", szMessage );     */
           cpl_frameset_insert( framelist, pFrameProduct );  
 
 
@@ -1282,7 +1271,7 @@ static int amber_BeamPos(
     else
     {
       sprintf( szMessage, "Missing FileName or Tag for Frame #%d", iFrameCount ); 
-      cpl_msg_info( fctid, szMessage );   
+      cpl_msg_info( fctid, "%s", szMessage );   
     } /* Filename and Tag present */    
     
     cur_frame = cpl_frameset_get_next( framelist );   
@@ -1291,7 +1280,7 @@ static int amber_BeamPos(
   if( iFrameCount != 22 )
   {
     sprintf( szMessage, "Error: Please input 22 raw files of type AMBER_BEAMPOS", iFrameCount ); 
-    cpl_msg_info( fctid, szMessage ); 
+    cpl_msg_info( fctid, "%s", szMessage ); 
     iStatus = 1;
   } 
 
