@@ -1,4 +1,4 @@
-/* $Id: amber_SciCal.c,v 1.48 2012/03/07 09:05:13 agabasch Exp $
+/* $Id: amber_SciCal.c,v 1.49 2013-09-16 14:56:43 agabasch Exp $
  *
  * This file is part of the AMBER Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -303,7 +303,7 @@ cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile )
 
 	/*
     sprintf( szMessage, "cpl_frame_set (\"%s\")", cpl_frame_get_filename(pframeSCIENCE[iProductNumber])  ); 
-    cpl_msg_info( fctid, szMessage );   
+    cpl_msg_info( fctid, "%s", szMessage );   
 	 */
 
 	/*
@@ -326,7 +326,7 @@ cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile )
 	 */
 	pHeader = cpl_propertylist_load(  szRawFile, 0 );
 	sprintf( szMessage, "Extracting product header from file %s for target named %s [%s].",  szRawFile,  cpl_propertylist_get_string( pHeader, "ESO OBS NAME" ), cpl_error_get_message()  );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	/*The ARCFILE is needed for the paf file in the selector and trf products*/
 	if (cpl_propertylist_has(pHeader, "ARCFILE") == 1)
@@ -366,7 +366,7 @@ cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile )
 	{
 		/* Error */
 		sprintf( szMessage, "Error in setting up the product header." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		iStatus = 16;
 	}
 #else 
@@ -381,7 +381,7 @@ cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile )
 	{
 		/* Error */
 		sprintf( szMessage, "Error in setting up the product header." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		iStatus = 16;
 	}
 #endif   
@@ -389,7 +389,7 @@ cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile )
 
 
 	sprintf( szMessage, "Header from file %s for target named %s [%s].",  szRawFile,  cpl_propertylist_get_string( pHeader, "ESO OBS NAME" ), cpl_error_get_message()  );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	/* Destroy tmpFrameset and implicitly its contents */
 	cpl_frameset_delete( frameSetTmp );
@@ -403,7 +403,7 @@ cpl_propertylist * SciCalCreateProduct( const char * fctid, char * szRawFile )
 	iError = CPL_ERROR_NONE;
 
 	sprintf( szMessage, "Creating product file%s...", szFilenameProduct );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	/*
 	 * Workaround:
@@ -462,34 +462,34 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 
 	/* Load bad pixel map */
 	sprintf( szMessage, "Loading BAD PIXEL MAP %s ...", badPixelFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	if( amdlibLoadBadPixelMap( badPixelFile, errMsg) != amdlibSUCCESS)
 	{
 		printf ("Could not load bad pixel map '%s'\n", badPixelFile);
-		cpl_msg_info( fctid, errMsg );
+		cpl_msg_info( fctid, "%s", errMsg );
 		return (amdlibFAILURE);
 	}
 
 	/* Load flat field map */
 	sprintf( szMessage, "Loading FLAT FIELD %s ...", flatFieldFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	if( amdlibLoadFlatFieldMap( flatFieldFile, errMsg)!=amdlibSUCCESS)
 	{
 		printf ("Could not load Flat Field file '%s'n", flatFieldFile);
-		cpl_msg_info( fctid, errMsg );
+		cpl_msg_info( fctid, "%s", errMsg );
 		return (amdlibFAILURE);
 	}
 
 	/* Load P2VM */
 	sprintf( szMessage, "Loading P2VM %s ...", p2vmFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	if( amdlibLoadP2VM( p2vmFile, &p2vm, errMsg) == amdlibFAILURE)
 	{
 		printf ("Could not load P2VM file '%s'\n", p2vmFile);
-		cpl_msg_info( fctid, errMsg );
+		cpl_msg_info( fctid, "%s", errMsg );
 		return (amdlibFAILURE);
 	}
 
@@ -497,7 +497,7 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 	if( amdlibGetWaveDataFromP2vm( &p2vm, &waveData, errMsg ) != amdlibSUCCESS)
 	{
 		printf ("Could not get wave data from P2VM file '%s'\n", p2vmFile);
-		cpl_msg_info( fctid, errMsg );
+		cpl_msg_info( fctid, "%s", errMsg );
 		return (amdlibFAILURE);
 	}
 
@@ -505,7 +505,7 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 	if (strlen(darkFile) != 0)
 	{
 		sprintf( szMessage, "Loading DARK (BIAS) %s ...\n", darkFile );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 		if (amdlibLoadRawData(darkFile, &rawData, errMsg) != amdlibSUCCESS)
 		{
@@ -514,13 +514,13 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 		}
 		/* Compute pixel bias map */
 		sprintf( szMessage, "Computing PIXEL BIAS MAP..." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 		if (amdlibGenerateDarkData(&rawData, &dark,
 				errMsg) != amdlibSUCCESS)
 		{
 			printf ("Could not generate pixel bias map\n");
-			cpl_msg_info( fctid, errMsg );
+			cpl_msg_info( fctid, "%s", errMsg );
 			return (amdlibFAILURE);
 		}
 		amdlibReleaseRawData(&rawData);
@@ -528,16 +528,16 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 	else
 	{
 		sprintf( szMessage, "No PIXEL BIAS MAP available due to no DARK file." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 		/* Load data file so that the false bias mimics its structure */
 		i=6;
 		sprintf( szMessage, "Getting PIXEL BIAS MAP from raw %s ...", inputFile );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		if (amdlibLoadRawData(inputFile, &rawData, errMsg) != amdlibSUCCESS)
 		{
 			sprintf( szMessage, "Could not load raw data file '%s'", inputFile);
-			cpl_msg_info( fctid, errMsg );
+			cpl_msg_info( fctid, "%s", errMsg );
 			return (amdlibFAILURE);
 		}
 		amdlibSetDarkData( &rawData,  &dark, 0.0, amdlibTYPICAL_RON , errMsg);
@@ -551,13 +551,13 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 		if (amdlibLoadRawData(skyFile, &rawData, errMsg) != amdlibSUCCESS)
 		{
 			printf ("Could not load sky file '%s'\n", skyFile);
-			cpl_msg_info( fctid, errMsg );
+			cpl_msg_info( fctid, "%s", errMsg );
 			return (amdlibFAILURE);
 		}
 		/* Equalize raw data */
 		if( amdlibCalibrateRawData( &dark, &rawData, errMsg) !=amdlibSUCCESS )
 		{
-			cpl_msg_info( fctid, errMsg );
+			cpl_msg_info( fctid, "%s", errMsg );
 			return (amdlibFAILURE);
 		}
 
@@ -565,7 +565,7 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 		if (amdlibRawData2ScienceData(&rawData, &waveData, &sky, amdlibTRUE, errMsg) != amdlibSUCCESS)
 		{
 			printf ("Could not get science data\n");
-			cpl_msg_info( fctid, errMsg );
+			cpl_msg_info( fctid, "%s", errMsg );
 			return (amdlibFAILURE);
 		}
 		/* if in JHK Mode, split Science Data in rows accordingly */
@@ -576,26 +576,26 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 	else
 	{
 		sprintf( szMessage, "No SKY will be  used...\n" );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		skyPtr = NULL;
 	}
 
 	/* Load data file */
 	sprintf( szMessage, "Loading RawData %s ...", inputFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 	if (amdlibLoadRawData(inputFile, &rawData, errMsg) != amdlibSUCCESS)
 	{
 		sprintf( szMessage, "Could not load raw data file '%s'", inputFile );
-		cpl_msg_info( fctid, szMessage );
-		cpl_msg_info( fctid, errMsg );
+		cpl_msg_info( fctid, "%s", szMessage );
+		cpl_msg_info( fctid, "%s", errMsg );
 		return (amdlibFAILURE);
 	}
 	/* Equalize raw data */
 	sprintf( szMessage, "Equalizing Raw Data." );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 	if (amdlibCalibrateRawData(&dark, &rawData, errMsg) !=amdlibSUCCESS)
 	{
-		cpl_msg_info( fctid, errMsg );
+		cpl_msg_info( fctid, "%s", errMsg );
 		return (amdlibFAILURE);
 	}
 
@@ -603,7 +603,7 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 	if (amdlibGetOiArrayFromRawData(&rawData, &array, errMsg) != amdlibSUCCESS)
 	{
 		sprintf( szMessage, "Warning -- Unable to retrieve OI_ARRAY information from input file");
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		amdlibReleaseOiArray(&array);
 	}
 
@@ -611,26 +611,26 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 	if (amdlibAllocateOiTarget(&target, 1) != amdlibSUCCESS)
 	{
 		printf ("Could not Allocate Target Structure\n");
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		return (amdlibFAILURE);
 	}
 	if (amdlibGetOiTargetFromRawData(&rawData,&target) != amdlibSUCCESS)
 	{
 		printf ("Could not Add to Target Structure\n");
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		return (amdlibFAILURE);
 	}
 
 
 	/* Produce science data */
 	sprintf( szMessage, "Producing Science Data..." );
-	cpl_msg_info( fctid, szMessage ); 
+	cpl_msg_info( fctid, "%s", szMessage ); 
 
 	if (amdlibRawData2ScienceData(&rawData, &waveData, &scienceData, amdlibFALSE,
 			errMsg) != amdlibSUCCESS)
 	{
 		printf ("Could not get science data");
-		cpl_msg_info( fctid, errMsg );
+		cpl_msg_info( fctid, "%s", errMsg );
 		return (amdlibFAILURE);
 	}
 
@@ -644,7 +644,7 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 		int nbChannels;
 
 		sprintf( szMessage, "Working on '%c' band", amdlibBandNumToStr(band));
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 		/* Compute visibilities */
 		nbChannels = amdlibComputeVisibilities
@@ -656,41 +656,41 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 		if (nbChannels == -1)
 		{
 			sprintf( szMessage, "Could NOT extract visibilities for '%c' band !", amdlibBandNumToStr(band));
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			return (amdlibFAILURE);
 		}
 		else if (nbChannels == 0)
 		{
 			sprintf( szMessage, "There is no channel for '%c' band", amdlibBandNumToStr(band));
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 		}
 		else
 		{
 			/* Print results */
 			sprintf( szMessage, "Band: %c", amdlibBandNumToStr(band) );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			if (vis2.nbBases == 1)
 			{
 				sprintf( szMessage, "         VIS (err)");
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 
 				sprintf( szMessage, "%12.3f (%8.03g)\n", imdVis2.vis12, imdVis2.sigmaVis12 );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 			}
 			else
 			{
 				sprintf( szMessage, "Global Averaged Visibilities Squared (using all Frames):");
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 
 				sprintf( szMessage, "       VIS 12 (err)          VIS 23 (err)          VIS 31 (err)");
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 				sprintf( szMessage, "%12.3f(%8.03g)  %12.3f(%8.03g)  %12.3f(%8.03g)",
 						imdVis2.vis12, imdVis2.sigmaVis12, imdVis2.vis12, imdVis2.sigmaVis12, imdVis2.vis31, imdVis2.sigmaVis31 );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 				sprintf( szMessage, "AverageClosurePhase (deg)= %8.03g  (%8.03g)", imdVis3.averageClosure,imdVis3.averageClosureError );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 			} /* 2 Tel or 3 Tel */
 
 #ifdef NEVER_PERFORM_FRAME_SELECTION_USE_AMBER_SELECTOR_AFTERWARDS	 
@@ -758,7 +758,7 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 			fFrame_GT_SNR2_Percent = 0.F;
 
 			sprintf( szMessage, "Number of Frames = %d",  imdVis.nbFrames );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			/* Count Frames with Fringe SNR greater than 2 */
 			for(iFrame = 0; iFrame < imdVis.nbFrames; iFrame++)
@@ -769,7 +769,7 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 			fFrame_GT_SNR2_Percent = (float)iFrame_GT_SNR2 / (float)imdVis.nbFrames;
 
 			sprintf( szMessage, "QC: %d of %d Frames having SNR greater than 2 = %0.2f percent", iFrame_GT_SNR2, imdVis.nbFrames, fFrame_GT_SNR2_Percent*100.0 );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			cpl_propertylist_append_long( qc_properties, "ESO QC FRAMES SELECTED SNRGT2", iFrame_GT_SNR2 );
 			cpl_propertylist_set_comment( qc_properties, "ESO QC FRAMES SELECTED SNRGT2", "Frames selected with SNR greater than 2 ");
@@ -810,7 +810,7 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 			if (strlen(szFilenameProduct) != 0)
 			{
 				sprintf ( szMessage, "Now writing Scientific Data to %s...", szFilenameProduct );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 
 
 
@@ -828,13 +828,13 @@ amdlibCOMPL_STAT amdlibExtractVisESO( const char *badPixelFile,
 				{
 					Status = amdlibFAILURE;
 					sprintf ( szMessage, "ERROR saving Scientific Data to %s.", szFilenameProduct );
-					cpl_msg_info( fctid, szMessage );
+					cpl_msg_info( fctid, "%s", szMessage );
 
 				}
 				else
 				{
 					sprintf ( szMessage, "Scientific Data %s saved successfully.", szFilenameProduct );
-					cpl_msg_info( fctid, szMessage );
+					cpl_msg_info( fctid, "%s", szMessage );
 
 					/* Now copy the file to tmp to be able to plot the files after the
 	         originals are renamed by ESOREX 
@@ -1258,13 +1258,13 @@ static int amber_SciCal(
 		iBinningOfFrames = 99999; /* Binning of all Frames */
 
 	sprintf ( szMessage, "BINNING of %d frames will be used", iBinningOfFrames );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	if( iBinningOfFrames == 1 )
 	{
 		errorType = amdlibTHEORETICAL_ERROR;
 		sprintf ( szMessage, "ERROR BAR calculation with amdlibTHEORETICAL_ERROR will be used for BINNING of 1 frame." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 	}
 
 
@@ -1280,7 +1280,7 @@ static int amber_SciCal(
 		strcpy( szFilenameFLAT, pszFilename );
 
 		sprintf ( szMessage, "FLAT FIELD identified %s", pszFilename );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 	}
 
 	cur_frame = cpl_frameset_find( framelist, "AMBER_BADPIX" );
@@ -1294,7 +1294,7 @@ static int amber_SciCal(
 		strcpy( szFilenameBADPIX, pszFilename );
 
 		sprintf ( szMessage, "BAD PIXEL MAP identified %s", pszFilename );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 	}
 
 	/* Try to load the optional SKY frame */
@@ -1317,7 +1317,7 @@ static int amber_SciCal(
 		strcpy( szFilenameSKY, pszFilename );
 
 		sprintf ( szMessage, "SKY identified %s", pszFilename );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 	}
 
@@ -1334,7 +1334,7 @@ static int amber_SciCal(
 		strcpy( szFilenameP2VM, pszFilename );
 
 		sprintf ( szMessage, "P2VM identified %s", pszFilename );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 	}
 	else
@@ -1350,7 +1350,7 @@ static int amber_SciCal(
 			strcpy( szFilenameP2VM, pszFilename );
 
 			sprintf ( szMessage, "P2VM identified %s", pszFilename );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 		}
 	}
 
@@ -1369,7 +1369,7 @@ static int amber_SciCal(
 		{
 			fclose( fpTmp );
 			sprintf ( szMessage, "latest pipeline P2VM identified %s", szFilenameP2VM );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 		}
 	}
 
@@ -1396,7 +1396,7 @@ static int amber_SciCal(
 		if( pszFilename && pszFileTag )
 		{
 			sprintf( szMessage, "Frame #%d [Current execution status=%d]", iFrameCount, iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			/* SCIENCE / CALIB DARK */
 			if(!strcmp( pszFileTag, "AMBER_DARK" ) ||
@@ -1407,7 +1407,7 @@ static int amber_SciCal(
 				strcpy( szFilenameDARK, pszFilename );
 
 				sprintf ( szMessage, "DARK identified %s", pszFilename );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 				iLoadedFrameCount++;
 			}
 
@@ -1433,7 +1433,7 @@ static int amber_SciCal(
 					strcpy( szFilenameSCIENCE[iReduction], pszFilename );
 					isFrameScience[iReduction] = 1;
 					sprintf ( szMessage, "SCIENCE identified %s", pszFilename );
-					cpl_msg_info( fctid, szMessage );
+					cpl_msg_info( fctid, "%s", szMessage );
 					iReduction++;
 					iLoadedFrameCount++;
 				} /* Status still OK */
@@ -1447,7 +1447,7 @@ static int amber_SciCal(
 					strcpy( szFilenameSCIENCE[iReduction], pszFilename );
 					isFrameScience[iReduction] = 0;
 					sprintf ( szMessage, "CALIB identified %s", pszFilename );
-					cpl_msg_info( fctid, szMessage );
+					cpl_msg_info( fctid, "%s", szMessage );
 					iReduction++;
 					iLoadedFrameCount++;
 				} /* Status still OK */
@@ -1458,7 +1458,7 @@ static int amber_SciCal(
 		else
 		{
 			sprintf( szMessage, "Missing FileName or Tag for Frame #%d", iFrameCount );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 		} /* Filename and Tag present */
 
 		cur_frame = cpl_frameset_get_next( framelist );
@@ -1471,7 +1471,7 @@ static int amber_SciCal(
 	{
 		/* This is a science object frame we can reduce the data now */
 		sprintf( szMessage, "Reducing %s now... [Status=%d]", szFilenameSCIENCE[i], iStatus );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 		cpl_msg_info( fctid, "Now calling high level data reduction amdlibExtractVisESO..." );
 		if( amdlibExtractVisESO( szFilenameBADPIX, szFilenameFLAT, szFilenameP2VM, szFilenameDARK, szFilenameSKY,
@@ -1480,7 +1480,7 @@ static int amber_SciCal(
 		)
 		{
 			sprintf( szMessage, "Error in Extracting Visibilities." );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = 2;
 		}
 		else
@@ -1503,7 +1503,7 @@ static int amber_SciCal(
 		if( pframeSCIENCE[i] )
 		{
 			sprintf( szMessage, "cpl_frame_insert (\"%s\")", cpl_frame_get_filename(pframeSCIENCE[i])  );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			cpl_frameset_insert( framelist, pframeSCIENCE[i] );
 		}
 	}
