@@ -1,4 +1,4 @@
-/* $Id: amber_ascii_export.c,v 1.8 2011/09/26 12:54:06 agabasch Exp $
+/* $Id: amber_ascii_export.c,v 1.9 2013-09-16 14:56:43 agabasch Exp $
  *
  * This file is part of the AMBER Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: agabasch $
- * $Date: 2011/09/26 12:54:06 $
- * $Revision: 1.8 $
- * $Name: amber-4_2_2 $
+ * $Date: 2013-09-16 14:56:43 $
+ * $Revision: 1.9 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -296,7 +296,7 @@ static int amber_ascii_export(
   strcpy( szMethod, cpl_parameter_get_string( cur_param ) );  
 
   sprintf ( szMessage, "Using Method: %s", szMethod );
-  cpl_msg_info( fctid, szMessage ); 
+  cpl_msg_info( fctid, "%s", szMessage ); 
   
 
   cpl_msg_info( fctid, "Start of DataReduction");
@@ -318,7 +318,7 @@ static int amber_ascii_export(
     if( pszFilename && pszFileTag )
     {
       sprintf( szMessage, "Frame #%d [Current execution status=%d]", iFrameCount, iStatus );
-      cpl_msg_info( fctid, szMessage );   
+      cpl_msg_info( fctid, "%s", szMessage );   
 
 
 
@@ -395,7 +395,7 @@ static int amber_ascii_export(
     iStatus = amdlibLoadOiFile( szFilnameOI, &insCfg, &array, &target, &photometry, &vis, &vis2, &vis3, &wave, &pst, &spectrum, errMsg );
 
     /*sprintf( szMessage, "%d", iStatus );
-    cpl_msg_info( fctid, szMessage );*/
+    cpl_msg_info( fctid, "%s", szMessage );*/
     
 
 
@@ -427,10 +427,10 @@ static int amber_ascii_export(
      pHeader = cpl_propertylist_load(  szFilnameOI, 0 ); 
 
      sprintf( szMessage, "Extracting product header from file %s for target named %s [%s].",  szFilnameOI,  cpl_propertylist_get_string( pHeader, "ESO OBS NAME" ), cpl_error_get_message()  ); 
-     cpl_msg_info( fctid, szMessage ); 
+     cpl_msg_info( fctid, "%s", szMessage ); 
 
      sprintf( szMessage, "Target observed on %s [%s].",  cpl_propertylist_get_string( pHeader, "DATE-OBS" ), cpl_error_get_message()  ); 
-     cpl_msg_info( fctid, szMessage );
+     cpl_msg_info( fctid, "%s", szMessage );
 
 
 
@@ -443,17 +443,17 @@ static int amber_ascii_export(
 
      
       sprintf ( szMessage, "Status: %d for input file %s [%s]", iStatus, szFilnameOI, errMsg );
-      cpl_msg_info( fctid, szMessage ); 
+      cpl_msg_info( fctid, "%s", szMessage ); 
       
       /* Count number of frames */
       int iTotal =  vis.nbFrames * vis.nbBases;
       sprintf( szMessage, "Number of Frames = %d giving %d Visibilities",  iTotal / vis.nbBases, iTotal );
-      cpl_msg_info( fctid, szMessage );
+      cpl_msg_info( fctid, "%s", szMessage );
 
       /* Count frames for Photometry and Piston */
       
         sprintf( szMessage, "Photometry: %d / Piston: %d", photometry.nbFrames, pst.nbFrames );
-        cpl_msg_info( fctid, szMessage );
+        cpl_msg_info( fctid, "%s", szMessage );
       
       
       /* Count Frames with Fringe SNR greater than xxx */
@@ -479,7 +479,7 @@ static int amber_ascii_export(
       if (amdlibGetBand(wave.wlen[wave.nbWlen-1]) != band)
       {
         sprintf ( szMessage, "Sorry, frame selection is only possible for one band. This data contains more than one band" );
-        cpl_msg_info( fctid, szMessage );       
+        cpl_msg_info( fctid, "%s", szMessage );       
 	iStatus = 666;
       }
       */
@@ -507,7 +507,7 @@ static int amber_ascii_export(
       } 
 
  sprintf ( szMessage, "New datetime format: %s", szFDATE);
-   cpl_msg_info( fctid, szMessage ); 
+   cpl_msg_info( fctid, "%s", szMessage ); 
 
 
       while (szFileName[iFName] != '\0')
@@ -518,7 +518,7 @@ static int amber_ascii_export(
       }
 
   sprintf ( szMessage, "New filename format: %s", szFileName);   
-     cpl_msg_info( fctid, szMessage );   
+     cpl_msg_info( fctid, "%s", szMessage );   
 
  
     
@@ -538,7 +538,7 @@ static int amber_ascii_export(
           strcpy( szASCII1, szBuffer );
 
  sprintf ( szMessage, "Yorick filename format: %s", szBuffer);
-   cpl_msg_info( fctid, szMessage ); 
+   cpl_msg_info( fctid, "%s", szMessage ); 
 
 
 
@@ -569,7 +569,7 @@ static int amber_ascii_export(
                    fp1 = fopen( szASCII1, "wt" );   
 
                    sprintf ( szMessage, "Yorick file %s  opened", szASCII1);
-                   cpl_msg_info( fctid, szMessage ); 
+                   cpl_msg_info( fctid, "%s", szMessage ); 
 
                                  
                  }
@@ -860,7 +860,7 @@ static int amber_ascii_export(
       /* not an AMBER file */
       iStatus = 2; 
       sprintf ( szMessage, "ERROR: Cannot read [%s]. OI table structure is not from AMBER or the file has been corrupted. [%s]", szFilnameOI, errMsg );
-      cpl_msg_info( fctid, szMessage ); 	
+      cpl_msg_info( fctid, "%s", szMessage ); 	
     }
    }
    else /* found fitting frame ? */
@@ -868,7 +868,7 @@ static int amber_ascii_export(
     /* no fitting frame */
     iStatus = 1; 
     sprintf ( szMessage, "ERROR: Current file doesn't contain SCIENCE_REDUCED or CALIB_REDUCED." );
-    cpl_msg_info( fctid, szMessage ); 	
+    cpl_msg_info( fctid, "%s", szMessage ); 	
    }
   
 
@@ -877,7 +877,7 @@ static int amber_ascii_export(
   else
   {
    sprintf( szMessage, "Missing FileName or Tag for Frame #%d", iFrameCount ); 
-   cpl_msg_info( fctid, szMessage );   
+   cpl_msg_info( fctid, "%s", szMessage );   
   } /* Filename and Tag present */    
 
     /* release memory */
@@ -902,14 +902,14 @@ static int amber_ascii_export(
  // {
     /*	  
     sprintf( szMessage, "cpl_frame_insert [%s]", cpl_frame_get_filename(pFrame ) ); 
-    cpl_msg_info( fctid, szMessage );     
+    cpl_msg_info( fctid, "%s", szMessage );     
     */
  //   cpl_frameset_insert( framelist, pFrame );  		  
  // }
   
   /*
   sprintf ( szMessage, "Status: %d for %s", iStatus, szProductfile );
-  cpl_msg_info( fctid, szMessage ); 
+  cpl_msg_info( fctid, "%s", szMessage ); 
   */
  
   cpl_msg_info( fctid, "End of DataReduction");
