@@ -1,4 +1,4 @@
-/* $Id: amber_detector.c,v 1.15 2011/09/26 13:20:08 agabasch Exp $
+/* $Id: amber_detector.c,v 1.16 2013-09-16 14:56:43 agabasch Exp $
  *
  * This file is part of the AMBER Pipeline
  * Copyright (C) 2002,iFrom03 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: agabasch $
- * $Date: 2011/09/26 13:20:08 $
- * $Revision: 1.15 $
- * $Name: amber-4_2_2 $
+ * $Date: 2013-09-16 14:56:43 $
+ * $Revision: 1.16 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -268,7 +268,7 @@ cpl_propertylist * DetectorCreateProductHeader( const char * fctid, char * szRaw
 	{
 		/* Error */
 		sprintf( szMessage, "Error in setting up the product header." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		iStatus = 16;
 	}
 #else 
@@ -283,7 +283,7 @@ cpl_propertylist * DetectorCreateProductHeader( const char * fctid, char * szRaw
 	{
 		/* Error */
 		sprintf( szMessage, "Error in setting up the product header." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		iStatus = 16;
 	}
 #endif
@@ -487,7 +487,7 @@ static int amber_detector(
 
 
 	sprintf( szMessage, "Using frames from %d to %d", iFrom, iTo );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 
 	/*
@@ -516,7 +516,7 @@ static int amber_detector(
 				iFrameCountFlat++;
 
 				sprintf( szMessage, "DETECTOR_FFM %d %s", iFrameCountFlat, pszFilename );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 			}
 
 			/* DETECTOR_DARK */
@@ -527,7 +527,7 @@ static int amber_detector(
 				iFrameCountDark++;
 
 				sprintf( szMessage, "DETECTOR_DARK %d %s", iFrameCountDark, pszFilename );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 			}
 		}
 
@@ -541,9 +541,9 @@ static int amber_detector(
 		iStatus = 1;
 
 		sprintf( szMessage, "Found %d of DARK and %d of FLAT frames.", iFrameCountDark, iFrameCountFlat );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		sprintf( szMessage, "Error: Please input 7 of each." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 	}
 
 	if( !iStatus )
@@ -553,7 +553,7 @@ static int amber_detector(
 		for( i=0; i<7 && !iStatus; i++ )
 		{
 			sprintf( szMessage, "amdmsCreateStatisticsAlgo for Darks #%d", i+1 );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreateStatisticsAlgo( &statEnv );
 
@@ -582,7 +582,7 @@ static int amber_detector(
 			statEnv->env.filter.aoiHeight = 512;
 
 			sprintf( szMessage, "amdmsAddFileToList: %s", szInputDark[i] );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			/* Prepare Input */
 			flags.content = amdmsIMAGING_DATA_CONTENT;
@@ -616,13 +616,13 @@ static int amber_detector(
 			amdmsAddFileToList( &(statEnv->env.outFiles),  szTemp,  flags);
 
 			sprintf( szMessage, "amdmsDoPixelStatistics" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = amdmsDoPixelStatistics( statEnv );
 			if( iStatus == amdmsSUCCESS )
 				iStatus = 0;
 
 			sprintf( szMessage, "Generating particle event maps: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsDestroyStatisticsAlgo( &statEnv );
 		} /* All 7 darks */
@@ -633,7 +633,7 @@ static int amber_detector(
 		for( i=0; i<7 && !iStatus; i++ )
 		{
 			sprintf( szMessage, "amdmsCreateStatisticsAlgo for Flats #%d", i+1 );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreateStatisticsAlgo( &statEnv );
 
@@ -663,7 +663,7 @@ static int amber_detector(
 			statEnv->env.filter.aoiHeight = 512;
 
 			sprintf( szMessage, "amdmsAddFileToList: %s", szInputFlat[i] );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			/* Prepare Input */
 			flags.content = amdmsIMAGING_DATA_CONTENT;
@@ -707,7 +707,7 @@ static int amber_detector(
 			amdmsAddFileToList( &(statEnv->env.outFiles),  szTemp,  flags);
 
 			sprintf( szMessage, "amdmsDoPixelStatistics" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = amdmsDoPixelStatistics( statEnv );
 			if( iStatus == amdmsSUCCESS )
 				iStatus = 0;
@@ -715,7 +715,7 @@ static int amber_detector(
 				iStatus = 666; /* Error from amdmslib */
 
 			sprintf( szMessage, "Generating particle event maps: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsDestroyStatisticsAlgo( &statEnv );
 		} /* All 7 flats */
@@ -726,7 +726,7 @@ static int amber_detector(
 		if( !iStatus )
 		{
 			sprintf( szMessage, "amdmsCreatePropertiesAlgo dark current maps for dark" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreatePropertiesAlgo( &ppEnv );
 
@@ -765,7 +765,7 @@ static int amber_detector(
 			amdmsAddFileToList( &(ppEnv->env.outFiles),  szTemp,  flags);
 
 			sprintf( szMessage, "amdmsDoProperties" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = amdmsDoProperties( ppEnv );
 			if( iStatus == amdmsSUCCESS )
 				iStatus = 0;
@@ -773,7 +773,7 @@ static int amber_detector(
 				iStatus = 666; /* Error from amdmslib */
 
 			sprintf( szMessage, "Generating dark current maps for dark: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsDestroyPropertiesAlgo( &ppEnv );
 		} /* Status still OK */
@@ -785,7 +785,7 @@ static int amber_detector(
 		{
 			/* a) Darks --------------------------------------------------------------------*/
 			sprintf( szMessage, " amdmsCreateBadPixelAlgo bad pixel map 1 of 6" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreateBadPixelAlgo( &badpixelEnv );
 
@@ -858,7 +858,7 @@ static int amber_detector(
 			amdmsAddFileToList( &(badpixelEnv->env.outFiles),  szTemp,  flags);
 
 			sprintf( szMessage, "amdmsDoBadPixel" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = amdmsDoBadPixel( badpixelEnv );
 			if( iStatus == amdmsSUCCESS )
 				iStatus = 0;
@@ -866,13 +866,13 @@ static int amber_detector(
 				iStatus = 666; /* Error from amdmslib */
 
 			sprintf( szMessage, "Generating bad pixel maps for dark: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsDestroyBadPixelAlgo( &badpixelEnv );
 
 			/* b) Flats --------------------------------------------------------------------*/
 			sprintf( szMessage, " amdmsCreateBadPixelAlgo bad pixel map 2 of 6" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreateBadPixelAlgo( &badpixelEnv );
 
@@ -946,7 +946,7 @@ static int amber_detector(
 			amdmsAddFileToList( &(badpixelEnv->env.outFiles),  szTemp,  flags);
 
 			sprintf( szMessage, "amdmsDoBadPixel" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = amdmsDoBadPixel( badpixelEnv );
 			if( iStatus == amdmsSUCCESS )
 				iStatus = 0;
@@ -954,13 +954,13 @@ static int amber_detector(
 				iStatus = 666; /* Error from amdmslib */
 
 			sprintf( szMessage, "Generating bad pixel maps for flat: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsDestroyBadPixelAlgo( &badpixelEnv );
 
 			/* c) ---------------------------------------------------------------------*/
 			sprintf( szMessage, " amdmsCreateBadPixelAlgo bad pixel map 3 of 6" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreateBadPixelAlgo( &badpixelEnv );
 
@@ -1059,7 +1059,7 @@ static int amber_detector(
 			amdmsAddFileToList( &(badpixelEnv->env.outFiles),  szTemp,  flags);
 
 			sprintf( szMessage, "amdmsDoBadPixel" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = amdmsDoBadPixel( badpixelEnv );
 			if( iStatus == amdmsSUCCESS )
 				iStatus = 0;
@@ -1067,13 +1067,13 @@ static int amber_detector(
 				iStatus = 666; /* Error from amdmslib */
 
 			sprintf( szMessage, "Generating bad pixel maps for flat: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsDestroyBadPixelAlgo( &badpixelEnv );
 
 			/* d) -----------------------------------------------------------------------*/
 			sprintf( szMessage, " amdmsCreateBadPixelAlgo bad pixel map 4 of 6" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreateBadPixelAlgo( &badpixelEnv );
 
@@ -1143,7 +1143,7 @@ static int amber_detector(
 			amdmsAddFileToList( &(badpixelEnv->env.outFiles),  szTemp,  flags);
 
 			sprintf( szMessage, "amdmsDoBadPixel" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = amdmsDoBadPixel( badpixelEnv );
 			if( iStatus == amdmsSUCCESS )
 				iStatus = 0;
@@ -1151,13 +1151,13 @@ static int amber_detector(
 				iStatus = 666; /* Error from amdmslib */
 
 			sprintf( szMessage, "Generating bad pixel maps for flat: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsDestroyBadPixelAlgo( &badpixelEnv );
 
 			/* e) -----------------------------------------------------------------------*/
 			sprintf( szMessage, " amdmsCreateBadPixelAlgo bad pixel map 5 of 6" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreateBadPixelAlgo( &badpixelEnv );
 
@@ -1224,7 +1224,7 @@ static int amber_detector(
 			amdmsAddFileToList( &(badpixelEnv->env.outFiles),  szTemp,  flags);
 
 			sprintf( szMessage, "amdmsDoBadPixel" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = amdmsDoBadPixel( badpixelEnv );
 			if( iStatus == amdmsSUCCESS )
 				iStatus = 0;
@@ -1232,13 +1232,13 @@ static int amber_detector(
 				iStatus = 666; /* Error from amdmslib */
 
 			sprintf( szMessage, "Generating bad pixel maps for flat: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsDestroyBadPixelAlgo( &badpixelEnv );
 
 			/* f) Finish --------------------------------------------------------------------*/
 			sprintf( szMessage, " amdmsCreateBadPixelAlgo bad pixel map 6 of 6" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreateBadPixelAlgo( &badpixelEnv );
 
@@ -1347,7 +1347,7 @@ static int amber_detector(
 				iStatus = 666; /* Error from amdmslib */
 
 			sprintf( szMessage, "Final stage -> Generating bad pixel maps for flat: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 
 
@@ -1361,7 +1361,7 @@ static int amber_detector(
 		for( i=0; i<7 && !iStatus; i++ )
 		{
 			sprintf( szMessage, "amdmsCreateStatisticsAlgo for Flats #%d", i+1 );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreateStatisticsAlgo( &statEnv );
 
@@ -1384,7 +1384,7 @@ static int amber_detector(
 
 
 			sprintf( szMessage, "amdmsAddFileToList: %s", szInputFlat[i] );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			/* Prepare Input */
 			flags.content = amdmsIMAGING_DATA_CONTENT;
@@ -1434,7 +1434,7 @@ static int amber_detector(
 			amdmsAddFileToList( &(statEnv->env.outFiles),  szTemp,  flags);
 
 			sprintf( szMessage, "amdmsDoPixelStatistics" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = amdmsDoPixelStatistics( statEnv );
 			if( iStatus == amdmsSUCCESS )
 				iStatus = 0;
@@ -1442,7 +1442,7 @@ static int amber_detector(
 				iStatus = 666; /* Error from amdmslib */
 
 			sprintf( szMessage, "Generating pixel statistics: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsDestroyStatisticsAlgo( &statEnv );
 		} /* All 7 flats */
@@ -1452,7 +1452,7 @@ static int amber_detector(
 		if( !iStatus )
 		{
 			sprintf( szMessage, "amdmsCreatePropertiesAlgo flatfield map" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsCreatePropertiesAlgo( &ppEnv );
 
@@ -1544,7 +1544,7 @@ static int amber_detector(
 
 
 			sprintf( szMessage, "amdmsDoProperties" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			iStatus = amdmsDoProperties( ppEnv );
 			if( iStatus == amdmsSUCCESS )
 				iStatus = 0;
@@ -1552,7 +1552,7 @@ static int amber_detector(
 				iStatus = 666; /* Error from amdmslib */
 
 			sprintf( szMessage, "Generating flat field map: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			amdmsDestroyPropertiesAlgo( &ppEnv );
 		}
@@ -1586,11 +1586,11 @@ static int amber_detector(
 
 			/* Add QC parameters */
 			sprintf( szMessage, "ESO QC BADPIX = %d", iBadPix );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			cpl_propertylist_append_int( qc_properties, "ESO QC BADPIX", iBadPix );
 
 			sprintf( szMessage, "ESO QC GOODPIX = %d", iGoodPix );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			cpl_propertylist_append_int( qc_properties, "ESO QC GOODPIX", iGoodPix );
 
 
@@ -1600,7 +1600,7 @@ static int amber_detector(
 			}
 
 			sprintf( szMessage, "ESO QC BADRATIO = %.2f", dBadRatio );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			cpl_propertylist_append_float( qc_properties, "ESO QC BADRATIO", dBadRatio );
 			cpl_propertylist_set_comment( qc_properties, "ESO QC BADRATIO", "Percentage of bad Pixels vs all Pixels");
 
@@ -1644,7 +1644,7 @@ static int amber_detector(
 			cpl_propertylist_delete( qcFromRawfile);
 
 			sprintf( szMessage, "First product is Bad Pixel Map: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			/*---------------------------------------------------------*/
 			strcpy( szProduct, "amber_eso_ffm.fits" );
@@ -1665,7 +1665,7 @@ static int amber_detector(
 			cpl_propertylist_delete( qc_properties);
 
 			sprintf( szMessage, "Second product is Flat Field Map: Status = %d", iStatus );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 		} /* STatus still OK */
 
