@@ -1,4 +1,4 @@
-/* $Id: amber_p2vm.c,v 1.24 2012/03/07 08:59:19 agabasch Exp $
+/* $Id: amber_p2vm.c,v 1.25 2013-09-16 14:56:43 agabasch Exp $
  *
  * This file is part of the AMBER Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: agabasch $
- * $Date: 2012/03/07 08:59:19 $
- * $Revision: 1.24 $
- * $Name: amber-4_2_2 $
+ * $Date: 2013-09-16 14:56:43 $
+ * $Revision: 1.25 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -287,7 +287,7 @@ int CreateProduct(const char * fctid, char * szRawFile,
 
 
 	sprintf( szMessage, "Extracting Header from file %s.",  szRawFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 
 
@@ -311,7 +311,7 @@ int CreateProduct(const char * fctid, char * szRawFile,
 	{
 		/* Error */
 		sprintf( szMessage, "Error in setting up the product header." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		cpl_msg_error(cpl_func,"Error in cpl_dfs_setup_product_header: %s %s",
 				cpl_error_get_message(),cpl_error_get_where());
 		iStatus = 16;
@@ -328,7 +328,7 @@ int CreateProduct(const char * fctid, char * szRawFile,
 	{
 		/* Error */
 		sprintf( szMessage, "Error in setting up the product header." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		cpl_msg_error(cpl_func,"Error in cpl_dfs_setup_product_header: %s %s",
 				cpl_error_get_message(),cpl_error_get_where());
 		iStatus = 16;
@@ -351,7 +351,7 @@ int CreateProduct(const char * fctid, char * szRawFile,
 	 */
 
 	sprintf( szMessage, "Creating Product %s...", szFilenameProduct );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	/*
 	 * Workaround:
@@ -389,7 +389,7 @@ int CreateProduct(const char * fctid, char * szRawFile,
 
 
 	sprintf( szMessage, "Writing Product Header..." );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	iStatus = 0;
 	if (CPL_ERROR_NONE != cpl_image_save(NULL, szFilenameProduct,
@@ -442,7 +442,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm3T_ESO(const char  * badPixelFile,
 
 	/* If a bad pixel file has been specified */
 	sprintf( szMessage, "Loading BAD PIXEL MAP %s ...", badPixelFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 	if ((badPixelFile != NULL) && (strlen(badPixelFile) != 0))
 	{
 		/* Load it */
@@ -456,7 +456,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm3T_ESO(const char  * badPixelFile,
 
 	/* Load flat field map */
 	sprintf( szMessage, "Loading FLAT FIELD %s ...", flatFieldFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	if( (flatFieldFile != NULL) && (strlen(flatFieldFile) != 0))
 	{
@@ -488,7 +488,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm3T_ESO(const char  * badPixelFile,
 
 		/* Load raw data */
 		sprintf( szMessage, "Loading P2VM file %s ...", inputFiles[i] );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		if (amdlibLoadRawData(inputFiles[i], &rawData, errMsg) != amdlibSUCCESS)
 		{
 			printf ("Could not load raw data file '%s'\n", inputFiles[i]);
@@ -507,7 +507,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm3T_ESO(const char  * badPixelFile,
 		{
 			sprintf( szMessage, "Computing Pixel Bias Map for P2VM file %s ...",
 					inputFiles[i] );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			/* Compute pixel bias map */
 			if (amdlibGenerateDarkData(&rawData, &dark, errMsg)
@@ -524,7 +524,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm3T_ESO(const char  * badPixelFile,
 			int p;
 
 			sprintf( szMessage, "Equalizing P2VM file %s ...", inputFiles[i] );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			/* Equalize raw data */
 			if( amdlibCalibrateRawData( &dark, &rawData, errMsg)
@@ -541,7 +541,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm3T_ESO(const char  * badPixelFile,
 			{
 				sprintf( szMessage, "Data in file %s is saturated!",
 						inputFiles[i] );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 			}
 
 			/* Get wave data from the first given file ??? check this -
@@ -568,14 +568,14 @@ amdlibCOMPL_STAT amdlibComputeP2vm3T_ESO(const char  * badPixelFile,
 				}
 
 				sprintf( szMessage, "Set new spectral Calibration." );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 
 				waveDataLoaded = amdlibTRUE;
 			}
 
 			/* Store calibrated data into P2VM data structure */
 			sprintf( szMessage, "Adding P2VM file %s ...", inputFiles[i] );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			if( amdlibAddToP2vmData( &rawData, &waveData, &p2vmData, errMsg)
 					!= amdlibSUCCESS)
 			{
@@ -595,7 +595,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm3T_ESO(const char  * badPixelFile,
 
 	/* Compute P2VM */
 	sprintf( szMessage, "Computing P2VM ..." );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	if( amdlibComputeP2VM( &p2vmData, amdlibP2VM_3T, &waveData, &p2vm, errMsg)
 			== amdlibFAILURE)
@@ -609,7 +609,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm3T_ESO(const char  * badPixelFile,
 	amdlibReleaseP2vmData(&p2vmData);
 
 	sprintf( szMessage, "Saving P2VM %s...", p2vmFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	if( amdlibSaveP2VM( p2vmFile, &p2vm, amdlibP2VM_UNKNOWN_ACC, errMsg)
 			== amdlibFAILURE )
@@ -652,7 +652,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm2T_ESO(const char  * badPixelFile,
 
 	/* If a bad pixel file has been specified */
 	sprintf( szMessage, "Loading BAD PIXEL MAP %s ...", badPixelFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 	if ((badPixelFile != NULL) && (strlen(badPixelFile) != 0))
 	{
 		/* Load it */
@@ -666,7 +666,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm2T_ESO(const char  * badPixelFile,
 
 	/* Load flat field map */
 	sprintf( szMessage, "Loading FLAT FIELD %s ...", flatFieldFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	if( (flatFieldFile != NULL) && (strlen(flatFieldFile) != 0))
 	{
@@ -698,7 +698,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm2T_ESO(const char  * badPixelFile,
 
 		/* Load raw data */
 		sprintf( szMessage, "Loading P2VM file %s ...", inputFiles[i] );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		if (amdlibLoadRawData(inputFiles[i], &rawData, errMsg) != amdlibSUCCESS)
 		{
 			printf ("Could not load raw data file '%s'\n", inputFiles[i]);
@@ -717,7 +717,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm2T_ESO(const char  * badPixelFile,
 		{
 			sprintf( szMessage, "Computing Pixel Bias Map for P2VM file %s ...",
 					inputFiles[i] );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			/* Compute pixel bias map */
 			if (amdlibGenerateDarkData(&rawData, &dark, errMsg)
@@ -734,7 +734,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm2T_ESO(const char  * badPixelFile,
 			int p;
 
 			sprintf( szMessage, "Equalizing P2VM file %s ...", inputFiles[i] );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			/* Equalize raw data */
 			if( amdlibCalibrateRawData( &dark, &rawData, errMsg)
@@ -751,7 +751,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm2T_ESO(const char  * badPixelFile,
 			{
 				sprintf( szMessage, "Data in file %s is saturated!",
 						inputFiles[i] );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 			}
 
 			/* Get wave data from the first given file ??? check this
@@ -778,14 +778,14 @@ amdlibCOMPL_STAT amdlibComputeP2vm2T_ESO(const char  * badPixelFile,
 				}
 
 				sprintf( szMessage, "Set new spectral Calibration." );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 
 				waveDataLoaded = amdlibTRUE;
 			}
 
 			/* Store calibrated data into P2VM data structure */
 			sprintf( szMessage, "Adding P2VM file %s ...", inputFiles[i] );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			if( amdlibAddToP2vmData( &rawData, &waveData, &p2vmData, errMsg)
 					!= amdlibSUCCESS)
 			{
@@ -805,7 +805,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm2T_ESO(const char  * badPixelFile,
 
 	/* Compute P2VM */
 	sprintf( szMessage, "Computing P2VM ..." );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	if( amdlibComputeP2VM( &p2vmData, amdlibP2VM_2T, &waveData, &p2vm, errMsg)
 			== amdlibFAILURE)
@@ -819,7 +819,7 @@ amdlibCOMPL_STAT amdlibComputeP2vm2T_ESO(const char  * badPixelFile,
 	amdlibReleaseP2vmData(&p2vmData);
 
 	sprintf( szMessage, "Saving P2VM %s...", p2vmFile );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	if( amdlibSaveP2VM( p2vmFile, &p2vm, amdlibP2VM_UNKNOWN_ACC, errMsg)
 			== amdlibFAILURE )
@@ -1214,7 +1214,7 @@ static int amber_p2vm(
 		strcpy( szFilenameFlat, pszFilename );
 
 		sprintf ( szMessage, "FLAT FIELD identified %s", pszFilename );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 	}
 
 	cur_frame = cpl_frameset_find( framelist, "AMBER_BADPIX" );
@@ -1228,7 +1228,7 @@ static int amber_p2vm(
 		strcpy( szFilenameBadPix, pszFilename );
 
 		sprintf ( szMessage, "BAD PIXEL MAP identified %s", pszFilename );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 	}
 
 	/* Do not continue without BADPIX and FALTFIELD */
@@ -1237,7 +1237,7 @@ static int amber_p2vm(
 		iStatus = 2;
 		sprintf ( szMessage, "Support Frames needed: AMBER_BADPIX and "
 				"AMBER_FLAT." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 		/* Close the amdlib logfile */
 		//if( fp )
@@ -1257,7 +1257,7 @@ static int amber_p2vm(
 		{
 			sprintf (szMessage, "Error: 10 Frames of type AMBER_3P2V are needed"
 					" or 5 Frames of type AMBER_2P2V are needed", pszFilename );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			iStatus = 666;
 		}
@@ -1274,7 +1274,7 @@ static int amber_p2vm(
 	 */
 	sprintf ( szMessage, "Searching for Spectral Calibration (WAVE) Files... "
 			"(current status = %d)", iStatus );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	cur_frame = cpl_frameset_get_first( framelist );
 
@@ -1293,7 +1293,7 @@ static int amber_p2vm(
 				/* Add to Framelist */
 				sprintf ( szMessage, "%d. 3WAVE identified %s", i3TelFrames+1,
 						pszFilename );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 				strcpy( szFilenameInWAVE[i3TelFrames], pszFilename );
 				i3TelFrames++;
 			}
@@ -1308,7 +1308,7 @@ static int amber_p2vm(
 					/* Add to Framelist */
 					sprintf ( szMessage, "%d. 2WAVE identified %s",
 							i2TelFrames+1, pszFilename );
-					cpl_msg_info( fctid, szMessage );
+					cpl_msg_info( fctid, "%s", szMessage );
 					strcpy( szFilenameInWAVE[i2TelFrames], pszFilename );
 					i2TelFrames++;
 				}
@@ -1324,12 +1324,12 @@ static int amber_p2vm(
 	if( i3TelFrames == 4 && !iStatus )
 	{
 		sprintf (szMessage, "Computing new Spectral Calibration for 3 Telecopes");
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 		/*sprintf ( szMessage, "[%s][%s][%s][%s][%s][%s]",
 		 * szFilenameBadPix, szFilenameFlat,  szFilenameInWAVE[0],
 		 * szFilenameInWAVE[1], szFilenameInWAVE[2], szFilenameInWAVE[3]  );
-    cpl_msg_info( fctid, szMessage ); */
+    cpl_msg_info( fctid, "%s", szMessage ); */
 
 
 		if (amdlibComputeSpectralCalibration3T(szFilenameBadPix, szFilenameFlat,
@@ -1339,7 +1339,7 @@ static int amber_p2vm(
 		{
 			iStatus = 5;
 			sprintf ( szMessage, "Could not compute Spectral Calibration" );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 		}
 		else
 		{
@@ -1363,7 +1363,7 @@ static int amber_p2vm(
 	{
 		sprintf ( szMessage, "Computing new Spectral Calibration for 2 "
 				"Telecopes (%s)...", szFilenameWave );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 		if (amdlibComputeSpectralCalibration2T(szFilenameBadPix, szFilenameFlat,
 				szFilenameInWAVE[0], szFilenameInWAVE[1], szFilenameInWAVE[2],
@@ -1395,7 +1395,7 @@ static int amber_p2vm(
 		sprintf ( szMessage, "No new Spectral Calibration computed "
 				"(no 4 AMBER_WAVE files!). "
 				"Using Calibration from DET1-Key in Header." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 	}
 
 	/*
@@ -1405,7 +1405,7 @@ static int amber_p2vm(
 	 */
 
 	sprintf ( szMessage, "Searching for 3P2V and 2P2V Files..." );
-	cpl_msg_info( fctid, szMessage );
+	cpl_msg_info( fctid, "%s", szMessage );
 
 	i3TelFrames = 0;
 	i2TelFrames = 0;
@@ -1425,7 +1425,7 @@ static int amber_p2vm(
 			{
 				/* Add to Framelist */
 				sprintf ( szMessage, "3P2V identified %s", pszFilename );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 				strcpy( szFilenameInP2VM[i3TelFrames], pszFilename );
 				i3TelFrames++;
 			}
@@ -1439,7 +1439,7 @@ static int amber_p2vm(
 				{
 					/* Add to Framelist */
 					sprintf ( szMessage, "2P2V identified %s", pszFilename );
-					cpl_msg_info( fctid, szMessage );
+					cpl_msg_info( fctid, "%s", szMessage );
 					strcpy( szFilenameInP2VM[i2TelFrames], pszFilename );
 					i2TelFrames++;
 				}
@@ -1459,11 +1459,11 @@ static int amber_p2vm(
 
 			/* Now make a DMD Product */
 			sprintf ( szMessage, "Create file and write header..." );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			CreateProduct(fctid,szFilenameInP2VM[0],szFilenameP2VM,zeroframes);
 
 			sprintf ( szMessage, "Now computing P2VM for 3 Telescopes..." );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 
 			if(amdlibComputeP2vm3T_ESO(szFilenameBadPix, szFilenameFlat,
 					szFilenameInP2VM[0],szFilenameInP2VM[1],szFilenameInP2VM[2],
@@ -1475,13 +1475,13 @@ static int amber_p2vm(
 			)
 			{
 				sprintf ( szMessage, "P2VM not computed due to errors." );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 				iStatus = 4;
 			}
 			else
 			{
 				sprintf ( szMessage, "P2VM produced: %s.", szFilenameP2VM );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 				iStatus = 0;
 
 				iWriteQC = 1;
@@ -1493,7 +1493,7 @@ static int amber_p2vm(
 		{
 			iStatus = 3;
 			sprintf ( szMessage, "10 Frames of type AMBER_3P2V are needed." );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 		}
 
 		if( i2TelFrames == 5 )
@@ -1502,11 +1502,11 @@ static int amber_p2vm(
 
 			/* Now make a DMD Product */
 			sprintf ( szMessage, "Create file and write header..." );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			CreateProduct(fctid,szFilenameInP2VM[0],szFilenameP2VM,zeroframes);
 
 			sprintf ( szMessage, "Now computing P2VM for 2 Telescopes..." );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 			if( amdlibComputeP2vm2T_ESO( szFilenameBadPix, szFilenameFlat,
 					szFilenameInP2VM[0],szFilenameInP2VM[1],szFilenameInP2VM[2],
 					szFilenameInP2VM[3],szFilenameInP2VM[4],
@@ -1516,13 +1516,13 @@ static int amber_p2vm(
 			)
 			{
 				sprintf ( szMessage, "P2VM not computed due to errors." );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 				iStatus = 4;
 			}
 			else
 			{
 				sprintf ( szMessage, "P2VM produced: %s.", szFilenameP2VM );
-				cpl_msg_info( fctid, szMessage );
+				cpl_msg_info( fctid, "%s", szMessage );
 				iStatus = 0;
 
 				iWriteQC = 1;
@@ -1535,7 +1535,7 @@ static int amber_p2vm(
 		{
 			iStatus = 3;
 			sprintf ( szMessage, "5 Frames of type AMBER_2P2V are needed." );
-			cpl_msg_info( fctid, szMessage );
+			cpl_msg_info( fctid, "%s", szMessage );
 		}
 
 	}
@@ -1544,7 +1544,7 @@ static int amber_p2vm(
 		iStatus = 2;
 		sprintf (szMessage,"Support Frames needed: "
 				"AMBER_BADPIX and AMBER_FLAT." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 	} /* No Flat of BadPix */
 
 	/* Close the amdlib logfile */
@@ -1571,7 +1571,7 @@ static int amber_p2vm(
 	if( iWriteQC )
 	{
 		sprintf ( szMessage, "Writing QC log file." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 
 		/* Reload the file to get the header */
 
@@ -1611,7 +1611,7 @@ static int amber_p2vm(
 	else
 	{
 		sprintf ( szMessage, "Error: Could not write QC log file." );
-		cpl_msg_info( fctid, szMessage );
+		cpl_msg_info( fctid, "%s", szMessage );
 		iStatus = 1;
 	}
 
